Icon loading and dispatch. Icon loading and dispatch.
Structs
- Freedesktop
Loader - Loader for freedesktop.org icon themes (GTK / Linux).
- Lucide
Loader - Loader for Lucide Icons (bundled SVG).
- Material
Loader - Loader for Google Material Symbols (bundled SVG).
- Segoe
Icons Loader - Loader for Windows Segoe Fluent Icons (Windows only).
- SfSymbols
Loader - Loader for Apple SF Symbols (macOS only).
Enums
- IconId
- Identifies what icon to load: a semantic role, a platform-specific name, or a custom provider.
- Icon
SetChoice - The user’s icon set selection mode.
Functions
- colorize_
monochrome_ svg - Colour a monochrome SVG icon in its bytes.
- default_
icon_ choice - Determine the default icon set choice for a theme.
- is_
freedesktop_ theme_ available - Check whether a freedesktop icon theme is installed on this system.
- list_
freedesktop_ themes - List installed freedesktop icon themes.
- load_
icon - Load an icon using the given set with default per-set options.
- load_
icon_ indicator - Load the animated loading indicator for the given set.