default_icon_choice

Function default_icon_choice 

pub fn default_icon_choice(
    icon_set: IconSet,
    icon_theme: Option<&str>,
) -> IconSetChoice
Determine the default icon set choice for a theme.

When the TOML specifies icon_theme (Some) and the theme is available (bundled sets are always available; freedesktop themes are checked via is_freedesktop_theme_available), returns IconSetChoice::Default(icon_theme).

When the TOML does not specify icon_theme (None), or the specified freedesktop theme is not installed, returns IconSetChoice::System.