pub struct MaterialLoader<'a> { /* private fields */ }Expand description
Loader for Google Material Symbols (bundled SVG).
Material SVGs are scalable at render time, so no size method.
Implementations
Sourceimpl<'a> MaterialLoader<'a>
impl<'a> MaterialLoader<'a>
Sourcepub fn new(id: impl Into<IconId<'a>>) -> Self
pub fn new(id: impl Into<IconId<'a>>) -> Self
Construct a new Material Symbols loader for the given icon id.
Sourcepub fn load(self) -> Option<IconData>
pub fn load(self) -> Option<IconData>
Load the icon, returning its data.
Requires the material-icons feature; None otherwise.
Sourcepub fn load_indicator() -> Option<AnimatedIcon>
pub fn load_indicator() -> Option<AnimatedIcon>
Load the Material animated spinner. Associated function; no self.
Requires the material-icons feature; None otherwise.