pub struct BorderSpec {
pub color: Option<Rgba>,
pub corner_radius: Option<f32>,
pub corner_radius_lg: Option<f32>,
pub line_width: Option<f32>,
pub opacity: Option<f32>,
pub shadow_enabled: Option<bool>,
pub padding_horizontal: Option<f32>,
pub padding_vertical: Option<f32>,
}Expand description
Border specification: color, geometry, and padding.
All fields are optional to support partial overlays – a BorderSpec with
only color set will only override the color when merged.
Fields
color: Option<Rgba>Border color.
corner_radius: Option<f32>Corner radius in logical pixels.
corner_radius_lg: Option<f32>Large corner radius in logical pixels (defaults only).
line_width: Option<f32>Border stroke width in logical pixels.
opacity: Option<f32>Border alpha multiplier 0.0–1.0 (defaults only).
shadow_enabled: Option<bool>Whether the bordered element has a drop shadow.
padding_horizontal: Option<f32>Horizontal padding inside the border in logical pixels.
padding_vertical: Option<f32>Vertical padding inside the border in logical pixels.
Implementations
Sourceimpl BorderSpec
impl BorderSpec
Sourcepub const FIELD_NAMES: &[&str]
pub const FIELD_NAMES: &[&str]
All serialized field names for BorderSpec, for TOML linting.
Sourceimpl BorderSpec
impl BorderSpec