Module bundled

Module bundled 

Bundled SVG icon lookup tables.

Functions

bundled_icon_by_name
Returns raw SVG bytes for a bundled icon looked up by its canonical name within the icon set.
bundled_icon_svg
Returns the raw SVG bytes for a bundled icon, if the corresponding feature flag is enabled.