Icon roles, sets, and provider trait.
Enums
- Icon
Data - Icon data returned by loading functions.
- Icon
Role - Semantic icon roles for cross-platform icon resolution.
- IconSet
- Known icon sets that provide platform-specific icon identifiers.
Traits
- Icon
Provider - Trait for types that map icon identifiers to platform-specific names and SVG data.
Functions
- detect_
icon_ theme - Detect the icon theme name for the current platform without caching.
- icon_
name - Look up the platform-specific icon identifier for a given icon set and role.
- system_
icon_ set - Detect the native icon set for the current operating system.
- system_
icon_ theme - Detect the icon theme name for the current platform.