#[non_exhaustive]pub enum Error {
Unsupported,
Unavailable(String),
Format(String),
Platform(Box<dyn Error + Send + Sync>),
}Expand description
Errors that can occur when reading or processing theme data.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unsupported
Operation not supported on the current platform.
Data source exists but cannot be read right now.
Format(String)
TOML parsing or serialization error.
Platform(Box<dyn Error + Send + Sync>)
Wrapped platform-specific error.