Module icons

Module icons 

Icon loading and dispatch. Icon loading and dispatch.

Structs

FreedesktopLoader
Loader for freedesktop.org icon themes (GTK / Linux).
LucideLoader
Loader for Lucide Icons (bundled SVG).
MaterialLoader
Loader for Google Material Symbols (bundled SVG).
SegoeIconsLoader
Loader for Windows Segoe Fluent Icons (Windows only).
SfSymbolsLoader
Loader for Apple SF Symbols (macOS only).

Enums

IconId
Identifies what icon to load: a semantic role, a platform-specific name, or a custom provider.
IconSetChoice
The user’s icon set selection mode.

Functions

colorize_monochrome_svg
Colour a monochrome SVG icon in its bytes.
default_icon_choice
Determine the default icon set choice for a theme.
is_freedesktop_theme_available
Check whether a freedesktop icon theme is installed on this system.
list_freedesktop_themes
List installed freedesktop icon themes.
load_icon
Load an icon using the given set with default per-set options.
load_icon_indicator
Load the animated loading indicator for the given set.