Module bundled
native_
theme
0.3.2
Module bundled
Module Items
Functions
In native_
theme::
model
native_theme
::
model
Module
bundled
Functions

bundled_
icon_
by_
name
Returns raw SVG bytes for a bundled icon looked up by its canonical name within the icon set.
bundled_
icon_
svg
Returns the raw SVG bytes for a bundled icon, if the corresponding feature flag is enabled.