#[non_exhaustive]pub struct ThemeColors {Show 36 fields
pub accent: Option<Rgba>,
pub background: Option<Rgba>,
pub foreground: Option<Rgba>,
pub surface: Option<Rgba>,
pub border: Option<Rgba>,
pub muted: Option<Rgba>,
pub shadow: Option<Rgba>,
pub primary_background: Option<Rgba>,
pub primary_foreground: Option<Rgba>,
pub secondary_background: Option<Rgba>,
pub secondary_foreground: Option<Rgba>,
pub danger: Option<Rgba>,
pub danger_foreground: Option<Rgba>,
pub warning: Option<Rgba>,
pub warning_foreground: Option<Rgba>,
pub success: Option<Rgba>,
pub success_foreground: Option<Rgba>,
pub info: Option<Rgba>,
pub info_foreground: Option<Rgba>,
pub selection: Option<Rgba>,
pub selection_foreground: Option<Rgba>,
pub link: Option<Rgba>,
pub focus_ring: Option<Rgba>,
pub sidebar: Option<Rgba>,
pub sidebar_foreground: Option<Rgba>,
pub tooltip: Option<Rgba>,
pub tooltip_foreground: Option<Rgba>,
pub popover: Option<Rgba>,
pub popover_foreground: Option<Rgba>,
pub button: Option<Rgba>,
pub button_foreground: Option<Rgba>,
pub input: Option<Rgba>,
pub input_foreground: Option<Rgba>,
pub disabled: Option<Rgba>,
pub separator: Option<Rgba>,
pub alternate_row: Option<Rgba>,
}Expand description
All theme colors as a flat set of 36 semantic color roles.
Organized into logical groups (core, primary, secondary, status, interactive, panel, component) but stored as direct fields for simpler access and flatter TOML serialization.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.accent: Option<Rgba>Brand or accent color for interactive elements.
background: Option<Rgba>Main application background color.
foreground: Option<Rgba>Main text color on the application background.
surface: Option<Rgba>Elevated surface color (cards, dialogs).
border: Option<Rgba>Default border color.
muted: Option<Rgba>Muted/subdued text color for secondary content.
shadow: Option<Rgba>Shadow or elevation color.
primary_background: Option<Rgba>Primary action background color.
primary_foreground: Option<Rgba>Text color on primary background.
secondary_background: Option<Rgba>Secondary action background color.
secondary_foreground: Option<Rgba>Text color on secondary background.
danger: Option<Rgba>Error or danger status color.
danger_foreground: Option<Rgba>Text color on danger background.
warning: Option<Rgba>Warning status color.
warning_foreground: Option<Rgba>Text color on warning background.
success: Option<Rgba>Success or positive status color.
success_foreground: Option<Rgba>Text color on success background.
info: Option<Rgba>Informational status color.
info_foreground: Option<Rgba>Text color on info background.
selection: Option<Rgba>Background color for selected items.
selection_foreground: Option<Rgba>Text color on selected background.
link: Option<Rgba>Hyperlink text color.
focus_ring: Option<Rgba>Color of keyboard focus indicators.
Sidebar background color.
Text color on sidebar background.
tooltip: Option<Rgba>Tooltip background color.
tooltip_foreground: Option<Rgba>Text color on tooltip background.
popover: Option<Rgba>Popover/dropdown background color.
popover_foreground: Option<Rgba>Text color on popover background.
Button background color.
Text color on button background.
input: Option<Rgba>Text input field background color.
input_foreground: Option<Rgba>Text color inside input fields.
disabled: Option<Rgba>Color for disabled UI elements.
separator: Option<Rgba>Separator/divider line color.
alternate_row: Option<Rgba>Alternating row background for lists and tables.
Implementations
Sourceimpl ThemeColors
impl ThemeColors