#[non_exhaustive]pub struct ThemeColors {Show 36 fields
pub accent: Option<Rgba>,
pub background: Option<Rgba>,
pub foreground: Option<Rgba>,
pub surface: Option<Rgba>,
pub border: Option<Rgba>,
pub muted: Option<Rgba>,
pub shadow: Option<Rgba>,
pub primary_background: Option<Rgba>,
pub primary_foreground: Option<Rgba>,
pub secondary_background: Option<Rgba>,
pub secondary_foreground: Option<Rgba>,
pub danger: Option<Rgba>,
pub danger_foreground: Option<Rgba>,
pub warning: Option<Rgba>,
pub warning_foreground: Option<Rgba>,
pub success: Option<Rgba>,
pub success_foreground: Option<Rgba>,
pub info: Option<Rgba>,
pub info_foreground: Option<Rgba>,
pub selection: Option<Rgba>,
pub selection_foreground: Option<Rgba>,
pub link: Option<Rgba>,
pub focus_ring: Option<Rgba>,
pub sidebar: Option<Rgba>,
pub sidebar_foreground: Option<Rgba>,
pub tooltip: Option<Rgba>,
pub tooltip_foreground: Option<Rgba>,
pub popover: Option<Rgba>,
pub popover_foreground: Option<Rgba>,
pub button: Option<Rgba>,
pub button_foreground: Option<Rgba>,
pub input: Option<Rgba>,
pub input_foreground: Option<Rgba>,
pub disabled: Option<Rgba>,
pub separator: Option<Rgba>,
pub alternate_row: Option<Rgba>,
}Expand description
All theme colors as a flat set of 36 semantic color roles.
Organized into logical groups (core, primary, secondary, status, interactive, panel, component) but stored as direct fields for simpler access and flatter TOML serialization.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.accent: Option<Rgba>background: Option<Rgba>foreground: Option<Rgba>surface: Option<Rgba>border: Option<Rgba>muted: Option<Rgba>shadow: Option<Rgba>primary_background: Option<Rgba>primary_foreground: Option<Rgba>secondary_background: Option<Rgba>secondary_foreground: Option<Rgba>danger: Option<Rgba>danger_foreground: Option<Rgba>warning: Option<Rgba>warning_foreground: Option<Rgba>success: Option<Rgba>success_foreground: Option<Rgba>info: Option<Rgba>info_foreground: Option<Rgba>selection: Option<Rgba>selection_foreground: Option<Rgba>link: Option<Rgba>focus_ring: Option<Rgba>tooltip: Option<Rgba>tooltip_foreground: Option<Rgba>popover: Option<Rgba>popover_foreground: Option<Rgba>input: Option<Rgba>input_foreground: Option<Rgba>disabled: Option<Rgba>separator: Option<Rgba>alternate_row: Option<Rgba>Implementations
Sourceimpl ThemeColors
impl ThemeColors