Skip to main contentModule icons
Source - IconData
- Icon data returned by loading functions.
- IconRole
- Semantic icon roles for cross-platform icon resolution.
- IconSet
- Known icon sets that provide platform-specific icon identifiers.
- IconProvider
- Trait for types that map icon identifiers to platform-specific names and SVG data.
- icon_name
- Look up the platform-specific icon identifier for a given icon set and role.
- system_icon_set
- Detect the native icon set for the current operating system.
- system_icon_theme
- Detect the icon theme name for the current platform.